@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2017 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtSCriptTools module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -351,46 +357,46 @@ void QScriptSyntaxHighlighter::highlightBlock(const QString &text)
                                     makeLastStandard = false;
                                     if (input != InputAlpha) {
                                         highlightWord(i, buffer);
-                                        buffer = QString::null;
+                                        buffer = QString();
                                     }
                                 } break;
             case StateCommentStart1:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = true;
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateCCommentStart2:
                                 setFormat(i - 1, 2, m_formats[ScriptCommentFormat]);
                                 makeLastStandard = false;
 //                                parentheses.push_back(Parenthesis(Parenthesis::Opened, QLatin1Char('/'), i-1));
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateScriptCommentStart2:
                                 setFormat(i - 1, 2, m_formats[ScriptCommentFormat]);
                                 makeLastStandard = false;
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateCComment:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, m_formats[ScriptCommentFormat]);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateScriptComment:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, m_formats[ScriptCommentFormat]);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateCCommentEnd1:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, m_formats[ScriptCommentFormat]);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateCCommentEnd2:
                                 if (makeLastStandard)
@@ -398,63 +404,63 @@ void QScriptSyntaxHighlighter::highlightBlock(const QString &text)
                                 makeLastStandard = false;
                                 setFormat(i, 1, m_formats[ScriptCommentFormat]);
 //                                parentheses.push_back(Parenthesis(Parenthesis::Closed, QLatin1Char('/'), i));
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateStringStart:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, emptyFormat);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateString:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, m_formats[ScriptStringFormat]);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateStringEnd:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, emptyFormat);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateString2Start:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, emptyFormat);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateString2:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, m_formats[ScriptStringFormat]);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateString2End:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, emptyFormat);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StateNumber:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, m_formats[ScriptNumberFormat]);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
             case StatePreProcessor:
                                 if (makeLastStandard)
                                     setFormat(i - 1, 1, emptyFormat);
                                 makeLastStandard = false;
                                 setFormat(i, 1, m_formats[ScriptPreprocessorFormat]);
-                                buffer = QString::null;
+                                buffer = QString();
                                 break;
         }
 
